# Generated by Django 2.2 on 2020-03-19 05:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xmail', '0002_auto_20150419_2120'),
    ]

    operations = [
        migrations.AlterField(
            model_name='asyncemailentry',
            name='state',
            field=models.CharField(choices=[('pending', 'Pending'), ('busy', 'Busy'), ('failed', 'Failed'), ('succeeded', 'Succeeded')], default='pending', help_text='Current state of the message (pending, busy, already sent, or failed)', max_length=10, verbose_name='Message state'),
        ),
    ]



from setuptools import setup

setup(
    name='django-xmail-ritual',
    version='1.1.2',
    packages=[
        'grimoire.django.xmail',
        'grimoire.django.xmail.management',
        'grimoire.django.xmail.management.commands',
        'grimoire.django.xmail.migrations',
    ],
    package_data={
        'grimoire.django.xmail': [
            'locale/*/LC_MESSAGES/*.*'
        ]
    },
    url='https://github.com/luismasuelli/django-xmail-ritual',
    license='LGPL',
    author='Luis y Anita',
    author_email='luismasuelli@hotmail.com',
    description='The xmail library is a mail dispatching library for Django 2.2 or greater. Mails are sent asynchronously by a '
                'management command',
    install_requires=['python-cantrips>=1.0.0', 'Django>=4.0']
)
